==> dl.php?src=linea21_2_3_0.zip: linea21/templates/public/2019/header.php <==
<?php
/**
 * @package linea21\core\public
 * @author $Author$ - linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */
?>
<head>
<meta charset="<?php echo CHARSET; ?>" />
<!--[if IE]><meta http-equiv="X-UA-Compatible" content="IE=edge"><![endif]-->
<?php if(ActiveItemKey($GLOBALS['activeitem']) == 'user-profile') { echo '<meta name="robots" content="noindex">'; } else { echo '<meta name="robots" content="index, follow" />'; }?>
<meta name="description" content="" />
<meta name="viewport" content="width=device-width, initial-scale=1.0, shrink-to-fit=no">
		<!--[if lt IE 9]>
		<script src="//html5shiv.googlecode.com/svn/trunk/html5.js"></script>
		<![endif]-->
<link rel="icon" type="image/gif" href="<?php echo PUBLIC_THEME_URL; ?>images/favicon.gif" />
<?php 
// hit internet explorer from IE7 to IE10 - may not work with user menu
// https://github.com/ampproject/amphtml/issues/17678#issuecomment-415731107
if (preg_match('~MSIE|Internet Explorer~i', $_SERVER['HTTP_USER_AGENT']) || (strpos($_SERVER['HTTP_USER_AGENT'], 'Trident/7.0; rv:11.0') !== false)) {
?>
<link rel="stylesheet" href="<?php echo PUBLIC_THEME_URL; ?>css/knacss/css/knacss-ie10-minified.css" media="all">
<?php } else { ?>
<link rel="stylesheet" href="<?php echo PUBLIC_THEME_URL; ?>css/knacss/css/knacss.css" media="all">
<?php } ?>
<link rel="stylesheet" href="<?php echo PUBLIC_THEME_URL; ?>css/style.css" media="all" />
<link rel="stylesheet" href="<?php echo PUBLIC_THEME_URL; ?>css/layout.css" media="all" />
<link rel="stylesheet" href="<?php echo SITE_ROOT_URL; ?>lib/vendor/font-awesome/css/font-awesome.min.css">
<link rel="stylesheet" href="<?php echo SITE_ROOT_URL; ?>lib/js/slick/slick/slick.css"/>
<link rel="stylesheet" href="<?php echo SITE_ROOT_URL; ?>lib/js/slick/slick/slick-theme.css"/>

<script src="<?php echo SITE_ROOT_URL; ?>lib/js/jquery-1.11.3.min.js"></script>
<script type="text/javascript" src="<?php echo SITE_ROOT_URL; ?>/lib/js/jquery-browser.js"></script>
<link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/animate.css/3.7.0/animate.css">
<script type="text/javascript" src="<?php echo SITE_ROOT_URL; ?>lib/js/waypoints/lib/jquery.waypoints.min.js"></script>

<script>
// from http://www.oxygenna.com/tutorials/scroll-animations-using-waypoints-js-animate-css
function onScrollInit( items, trigger ) {
  items.each( function() {
    var osElement = $(this),
        osAnimationClass = osElement.attr('data-os-animation'),
        osAnimationDelay = osElement.attr('data-os-animation-delay');
      
        osElement.css({
          '-webkit-animation-delay':  osAnimationDelay,
          '-moz-animation-delay':     osAnimationDelay,
          'animation-delay':          osAnimationDelay
        });

        var osTrigger = ( trigger ) ? trigger : osElement;
        
        osTrigger.waypoint(function() {
          osElement.addClass('animated').addClass(osAnimationClass);
          },{
              triggerOnce: true,
              offset: '90%'
        });
  });
}

$(document).ready(function() {
	onScrollInit( $('.os-animation') );
});
</script>
<?php if(defined('AJAX_LOGIN') && AJAX_LOGIN == 1) echo '<script src="'.SITE_ROOT_URL.'lib/js/leanModal.v1.1/jquery.leanModal.min.js"></script>'; ?>
<script src="<?php echo SITE_ROOT_URL; ?>lib/js/functions.js"></script>
<link rel="stylesheet" href="<?php echo PUBLIC_THEME_URL; ?>css/print.css" media="print" />
<link rel="alternate" title="RSS2" href="rss2.php" />
<?php distInclude(THEME_PUBLIC_PATH.'meta_data.php', THEME_PUBLIC_DIST); ?>
<?php
IncludeColorboxJs(array("a[href$='.jpg'],a[href$='.jpeg'],a[href$='.png'],a[href$='.gif'], a[href$='.JPG'],a[href$='.JPEG'],a[href$='.PNG'],a[href$='.GIF']"));
AddDynamicHeader();
?>
<title></title>
<?php if(isset($GLOBALS['debugbar'])) echo $GLOBALS['debugbarRenderer']->renderHead(); ?>
</head>

==> dl.php?src=linea21_2_5_0.zip: linea21/templates/public/2019/header.php <==
<?php
/**
 * @package linea21\core\public
 * @author $Author$ - linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */
?>
<?php
if(MOD_DEBUG == 1) $csuffix = '?v='. time(); else $csuffix= '';
?>
<head>
<meta charset="<?php echo CHARSET; ?>" />
<!--[if IE]><meta http-equiv="X-UA-Compatible" content="IE=edge"><![endif]-->
<?php if(ActiveItemKey($GLOBALS['activeitem']) == 'user-profile') { echo '<meta name="robots" content="noindex">'; } else { echo '<meta name="robots" content="index, follow" />'; }?>
<meta name="description" content="" />
<meta name="viewport" content="width=device-width, initial-scale=1.0, shrink-to-fit=no">
		<!--[if lt IE 9]>
		<script src="//html5shiv.googlecode.com/svn/trunk/html5.js"></script>
		<![endif]-->
<link rel="icon" type="image/gif" href="<?php echo PUBLIC_THEME_URL; ?>images/favicon.gif" />
<?php 
// hit internet explorer from IE7 to IE10 - may not work with user menu
// https://github.com/ampproject/amphtml/issues/17678#issuecomment-415731107
if (preg_match('~MSIE|Internet Explorer~i', $_SERVER['HTTP_USER_AGENT']) || (strpos($_SERVER['HTTP_USER_AGENT'], 'Trident/7.0; rv:11.0') !== false)) {
?>
<link rel="stylesheet" href="<?php echo PUBLIC_THEME_URL; ?>css/knacss/css/knacss-ie10-minified.css" media="all">
<?php } else { ?>
<link rel="stylesheet" href="<?php echo PUBLIC_THEME_URL; ?>css/knacss/css/knacss.css" media="all">
<?php } ?>
<link rel="stylesheet" href="<?php echo PUBLIC_THEME_URL . 'css/style.css' . $csuffix; ?>" media="all" />
<link rel="stylesheet" href="<?php echo PUBLIC_THEME_URL . 'css/layout.css' . $csuffix; ?>" media="all" />
<link rel="stylesheet" href="<?php echo SITE_ROOT_URL; ?>lib/vendor/font-awesome/css/font-awesome.min.css">
<link rel="stylesheet" href="<?php echo SITE_ROOT_URL; ?>lib/js/slick/slick/slick.css"/>
<link rel="stylesheet" href="<?php echo SITE_ROOT_URL; ?>lib/js/slick/slick/slick-theme.css"/>

<script src="<?php echo SITE_ROOT_URL; ?>lib/js/jquery-1.11.3.min.js"></script>
<script src="<?php echo SITE_ROOT_URL; ?>lib/js/jquery-browser.js"></script>
<link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/animate.css/3.7.0/animate.css">
<script src="<?php echo SITE_ROOT_URL; ?>lib/js/waypoints/lib/jquery.waypoints.min.js"></script>

<script>
// from http://www.oxygenna.com/tutorials/scroll-animations-using-waypoints-js-animate-css
function onScrollInit( items, trigger ) {
  items.each( function() {
    var osElement = $(this),
        osAnimationClass = osElement.attr('data-os-animation'),
        osAnimationDelay = osElement.attr('data-os-animation-delay');
      
        osElement.css({
          '-webkit-animation-delay':  osAnimationDelay,
          '-moz-animation-delay':     osAnimationDelay,
          'animation-delay':          osAnimationDelay
        });

        var osTrigger = ( trigger ) ? trigger : osElement;
        
        osTrigger.waypoint(function() {
          osElement.addClass('animated').addClass(osAnimationClass);
          },{
              triggerOnce: true,
              offset: '90%'
        });
  });
}

$(document).ready(function() {
	onScrollInit( $('.os-animation') );
	
	$("a.toggle").click(function() {
		   var tar = $(this).data("target");
			// console.log(tar);
        $("#" + tar).fadeToggle();
			return false;
     });
});
</script>
<?php if(defined('AJAX_LOGIN') && AJAX_LOGIN == 1) echo '<script src="'.SITE_ROOT_URL.'lib/js/leanModal.v1.1/jquery.leanModal.min.js"></script>'; ?>
<script src="<?php echo SITE_ROOT_URL; ?>lib/js/functions.js"></script>
<link rel="stylesheet" href="<?php echo PUBLIC_THEME_URL; ?>css/print.css" media="print" />
<link rel="alternate" title="RSS2" href="rss2.php" />
<?php distInclude(THEME_PUBLIC_PATH.'meta_data.php', THEME_PUBLIC_DIST); ?>
<?php
IncludeColorboxJs(array("a[href$='.jpg'],a[href$='.jpeg'],a[href$='.png'],a[href$='.gif'], a[href$='.JPG'],a[href$='.JPEG'],a[href$='.PNG'],a[href$='.GIF']"));
AddDynamicHeader();
?>
<title></title>
<?php if(isset($GLOBALS['debugbar'])) echo $GLOBALS['debugbarRenderer']->renderHead(); ?>
</head>
